.. _install-plugin-registry:

===============
Plugin Registry
===============

This is a list of horizon plugins which are part of the official
OpenStack releases.

.. note::

   Currently, Horizon plugins are responsible for their own compatibility.
   Check the individual repos for information on support.

.. The CSV file is generated based the openstack/releases deliverables
   by tools/list-horizon-plugins.py. If you would like to know the detail
   on how they are processed, see the script above.

.. csv-table::
   :header-rows: 1
   :file: ../../../plugin-registry.csv
